function evol_trans_rate(id_trans)
% EVOL_TRANS_RATE(ID_TRANS)
%   Extract the number of transitions with id number ID_TRANS from ReSCAL logs
%   and plot the evolution of the overall rate.

time_flag=1;

%% read header of TRANS.log
fprintf('reading TRANS.log\n');
fid=fopen('TRANS.log');
if (fid==-1)
  fprintf('file not found\n');
  return
end
textscan(fid,'# TRANSITIONS');
C=textscan(fid,'NB_TRANS_DB = %d');
nb_trans=C{1};
for i=1:nb_trans
  CTrans=textscan(fid,'TR%[^\n]s');
end

%% skip line of text
C=textscan(fid,'%[^\n]s');
%celldisp(C)

C=textscan(fid,'NB_TRANS_CEL = %d');
if size(C{1})>0
  nb_tcel=C{1};
else
  nb_tcel=0;
end

for i=1:nb_tcel
  CTransCel=textscan(fid,'TR1%[^\n]s');
end

%% skip line of text
C=textscan(fid,'%[^\n]s');
%celldisp(C)

C=textscan(fid,'NB_LINKS = %d');
if size(C{1})>0
  nb_link=C{1};
else
  nb_link=0;
end
for i=1:nb_link
  CLinks=textscan(fid,'LT%[^\n]s');
end

C=textscan(fid,'%[^\n]s');
%celldisp(C)

%% read column headers
id=-1;
col_trans=-1;
nc=0;
%while (id~=id_trans) & (id~=nb_trans-1)
while (id~=nb_trans-1)
  C=textscan(fid,'TR( %d)');
  %celldisp(C)
  n=size(C{1},1);
  if n>0
    if (id < id_trans) & (id+n >= id_trans)
      col_trans=nc+(id_trans-id);
      fprintf('data for transition %d are located in column %d (+1)\n', id_trans, col_trans);
    end
    id=C{1}(n);
    nc=nc+n;
  end
  %C=textscan(fid,'%[BLK]s');
  %C=textscan(fid,'%[ ]BLK');
  C=textscan(fid,'B%[LK]');
  %keyboard
  %celldisp(C)
  if size(C{1},1)>0
    nc=nc+1;
  end
  %pause(1)
end

if nb_tcel>0
  id=-1;
  while (id~=nb_tcel-1)
    C=textscan(fid,'TR1( %d)');
    %celldisp(C);
    n=size(C{1},1);
    if n>0
      id=C{1}(n);
      nc=nc+n;
    end
  end
end

if nb_link>0
  id=-1;
  while (id~=nb_link-1)
    C=textscan(fid,'LT( %d)');
    %celldisp(C);
    n=size(C{1},1);
    if n>0
      id=C{1}(n);
      nc=nc+n;
    end
  end
end

fprintf('total number of columns: %d (+1)\n', nc);

%return

%% read trans data
C=textscan(fid,'%d','delimiter',':');
data0=cell2mat(C);
l=size(data0,1);
nb=l/(nc+1);
fprintf('number of records: %d\n', nb);
data=reshape(data0,nc+1,nb)';
transdata=data(:,col_trans+1);
fclose(fid);

%% read time data
fprintf('reading TIME.log\n');
fid=fopen('TIME.log');
if (fid==-1)
  fprintf('file not found\n');
  return
end
C=textscan(fid,'%[^\n]s');
%celldisp(C)
C=textscan(fid,'%f','delimiter',':dhms');
data0=cell2mat(C);
l=size(data0,1);
nb=nb+1;
c=l/nb;
data=reshape(data0,c,nb)';
time0=data(1,4);
timedata=data(2:nb,4);
dtimedata=data(2:nb,5);
fclose(fid);

%keyboard

%% plot data
figure
hold on
lw=0.5;
title(sprintf('Mean rate of occurences of transition %d', id_trans))
plot(timedata,double(transdata)./dtimedata,'linewidth',lw)
xlabel('Time [t_{0}]')
ylabel('Rate [t_{0}^-1]')
grid on

avg=mean(transdata);
fprintf('average number of occurences per record: %f\n', avg);
dt=max(timedata)-time0;
if dt>0
  avg_norm=sum(transdata)/dt;
  fprintf('overall rate of occurences: %f t_0^-1\n', avg_norm);
end
%keyboard

return

